@@ -1,6 +1,6 @@
 /*** tzraw.c -- reader for olson database zoneinfo files
  *
- * Copyright (C) 2009-2022 Sebastian Freundt
+ * Copyright (C) 2009-2024 Sebastian Freundt
  *
  * Author:  Sebastian Freundt <freundt@ga-group.nl>
  *
@@ -702,7 +702,7 @@ main(int argc, char *argv[])
 		printf("  nlp\t%zu\n", z->nlp);
 
 		for (size_t j = 0U; j < z->ntr; j++) {
-			printf("    tr[%zu]\t%ld\t%hhu\n", j, z->trs[j], z->tys[j]);
+			printf("    tr[%zu]\t%lld\t%hhu\n", j, z->trs[j], z->tys[j]);
 		}
 		for (size_t j = 0U; j < z->nty; j++) {
 			printf("    of[%zu]\t%d\n", j, z->ofs[j]);
