@@ -1,6 +1,6 @@
 /*** dconv.c -- convert calendrical and time stamp systems
  *
- * Copyright (C) 2011-2022 Sebastian Freundt
+ * Copyright (C) 2011-2024 Sebastian Freundt
  *
  * Author:  Sebastian Freundt <freundt@ga-group.nl>
  *
@@ -144,11 +144,19 @@ main(int argc, char *argv[])
 	}
 
 	/* try and read the from and to time zones */
-	if (argi->from_zone_arg) {
-		fromz = dt_io_zone(argi->from_zone_arg);
+	if (argi->from_zone_arg &&
+	    (fromz = dt_io_zone(argi->from_zone_arg)) == NULL) {
+		error("\
+Error: cannot find zone specified in --from-zone: `%s'", argi->from_zone_arg);
+		rc = 1;
+		goto clear;
 	}
-	if (argi->zone_arg) {
-		z = dt_io_zone(argi->zone_arg);
+	if (argi->zone_arg &&
+	    (z = dt_io_zone(argi->zone_arg)) == NULL) {
+		error("\
+Error: cannot find zone specified in --zone: `%s'", argi->zone_arg);
+		rc = 1;
+		goto clear;
 	}
 	if (argi->base_arg) {
 		struct dt_dt_s base = dt_strpdt(argi->base_arg, NULL, NULL);
