@@ -1,6 +1,6 @@
 /*** strptime.c -- a shell interface to strptime(3)
  *
- * Copyright (C) 2011-2022 Sebastian Freundt
+ * Copyright (C) 2011-2024 Sebastian Freundt
  *
  * Author:  Sebastian Freundt <freundt@ga-group.nl>
  *
@@ -54,7 +54,7 @@ const char *prog = "strptime";
 
 
 static int
-pars_line(struct tm *tm, const char *const *fmt, size_t nfmt, const char *line)
+pars_line(struct tm *tm, char *const *fmt, size_t nfmt, const char *line)
 {
 	for (size_t i = 0; i < nfmt; i++) {
 		if (fmt[i] && strptime(line, fmt[i], tm) != NULL) {
@@ -75,7 +75,7 @@ prnt_line(const char *ofmt, struct tm *tm)
 
 static int
 proc_line(
-	const char *ln, const char *const *fmt, size_t nfmt,
+	const char *ln, char *const *fmt, size_t nfmt,
 	const char *ofmt,
 	int quietp)
 {
@@ -94,7 +94,7 @@ proc_line(
 }
 
 static int
-proc_lines(const char *const *fmt, size_t nfmt, const char *ofmt, int quietp)
+proc_lines(char *const *fmt, size_t nfmt, const char *ofmt, int quietp)
 {
 	size_t lno = 0;
 	int rc = 0;
